==> camel-core-2.10.0-sources.jar: org/apache/camel/api/management/mbean/ManagedProducerCacheMBean.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.api.management.mbean;

import org.apache.camel.api.management.ManagedAttribute;
import org.apache.camel.api.management.ManagedOperation;

public interface ManagedProducerCacheMBean extends ManagedServiceMBean {

    @ManagedAttribute(description = "Source")
    String getSource();

    @ManagedAttribute(description = "Number of elements cached")
    Integer getSize();

    @ManagedAttribute(description = "Maximum cache size (capacity)")
    Integer getMaximumCacheSize();

    @ManagedAttribute(description = "Cache hits")
    Long getHits();

    @ManagedAttribute(description = "Cache misses")
    Long getMisses();

    @ManagedOperation(description = "Reset cache statistics")
    void resetStatistics();

    @ManagedOperation(description = "Purges the cache")
    void purge();

}

==> camel-core-2.15.3-sources.jar: org/apache/camel/api/management/mbean/ManagedProducerCacheMBean.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.api.management.mbean;

import org.apache.camel.api.management.ManagedAttribute;
import org.apache.camel.api.management.ManagedOperation;

public interface ManagedProducerCacheMBean extends ManagedServiceMBean {

    @ManagedAttribute(description = "Source")
    String getSource();

    @ManagedAttribute(description = "Number of elements cached")
    Integer getSize();

    @ManagedAttribute(description = "Maximum cache size (capacity)")
    Integer getMaximumCacheSize();

    @ManagedAttribute(description = "Cache hits")
    Long getHits();

    @ManagedAttribute(description = "Cache misses")
    Long getMisses();

    @ManagedAttribute(description = "Cache evicted")
    Long getEvicted();

    @ManagedOperation(description = "Reset cache statistics")
    void resetStatistics();

    @ManagedOperation(description = "Purges the cache")
    void purge();

    @ManagedAttribute(description = "EventNotifier enabled")
    Boolean isEventNotifierEnabled();

}
